summaryrefslogtreecommitdiff
path: root/Cydia.mm
diff options
context:
space:
mode:
Diffstat (limited to 'Cydia.mm')
-rw-r--r--Cydia.mm6
1 files changed, 5 insertions, 1 deletions
diff --git a/Cydia.mm b/Cydia.mm
index 02c2ae9..f42afe3 100644
--- a/Cydia.mm
+++ b/Cydia.mm
@@ -5264,7 +5264,11 @@ bool DepSubstrate(const pkgCache::VerIterator &iterator) {
}
- (void) reloadButtonClicked {
- // You don't reload a package view by clicking the button.
+ // Don't reload a package view by clicking the button.
+}
+
+- (void) applyLoadingTitle {
+ // Don't show "Loading" as the title. Ever.
}
#endif